@@ -34,6 +34,6 @@ fn main() {
         thread.join().unwrap();
     }
 
-    print!("{}", "\n".repeat(3));
+    eprint!("{}", "\n".repeat(3));
     println!("completed!");
 }
