@@ -8,6 +8,7 @@ fn main() {
             }
         }
     }
-    print!("{}", "\n".repeat(3));
+
+    eprint!("{}", "\n".repeat(3));
     println!("completed!");
 }
