@@ -12,7 +12,7 @@ fn main() {
     let mut pb2 = tqdm!(
         total = render_length,
         desc = "ascii   ".to_string(),
-        ascii = true,
+        animation = Animation::TqdmAscii,
         position = 2,
         max_fps = true
     );
@@ -49,5 +49,5 @@ fn main() {
         std::thread::sleep(std::time::Duration::from_secs_f32(0.02));
     }
 
-    print!("{}", "\n".repeat(9));
+    eprint!("{}", "\n".repeat(9));
 }
